// src/api/polkadot.api.ts
import { ApiPromise, WsProvider } from "@polkadot/api";
import LRU from "lru-cache";
var cache = new LRU({
  max: 20,
  dispose: async (promise) => {
    const api = await promise;
    if (api.isConnected) {
      api.disconnect();
    }
  }
});
async function getPolkadotApi(ws, onDisconnect) {
  const promise = cache.get(ws) || ApiPromise.create({
    provider: new WsProvider(ws)
  });
  cache.set(ws, promise);
  const api = await promise;
  await api.isReady;
  if (onDisconnect) {
    api.once("disconnected", onDisconnect);
  }
  return api;
}

// src/handlers/handlers.interfaces.ts
var ExtrinsicStatus = /* @__PURE__ */ ((ExtrinsicStatus2) => {
  ExtrinsicStatus2["Failed"] = "Failed";
  ExtrinsicStatus2["Sent"] = "Sent";
  ExtrinsicStatus2["Success"] = "Success";
  return ExtrinsicStatus2;
})(ExtrinsicStatus || {});

// src/handlers/createExtrinsicEventHandler.ts
function createExtrinsicEventHandler(pallet, successEvent, cb) {
  return ({ events = [], status, txHash }) => {
    const hash = txHash.toHex();
    if (status.isReady) {
      cb({ status: "Sent" /* Sent */, txHash: hash });
    }
    if (status.isInBlock) {
      const block = status.asInBlock.toString();
      events.forEach(({ event: { data, method, section } }) => {
        var _a;
        if (section === pallet && method === successEvent) {
          if (method === "Attempted") {
            const eventData = data.at(0);
            if (eventData.isIncomplete) {
              cb({
                status: "Failed" /* Failed */,
                blockHash: block,
                txHash: hash,
                message: (_a = eventData.asIncomplete) == null ? void 0 : _a.toHuman().join("; ")
              });
              return;
            }
          }
          cb({
            status: "Success" /* Success */,
            blockHash: block,
            txHash: hash
          });
        }
        if (section === "system" && method === "ExtrinsicFailed") {
          cb({
            status: "Failed" /* Failed */,
            blockHash: block,
            txHash: hash,
            message: data.join("; ")
          });
        }
      });
    }
  };
}

// src/handlers/createTxEventHandler.ts
async function createTxEventHandler(ethersSigner, txHash, cb, skipSentEvent = false) {
  if (!ethersSigner.provider) {
    throw new Error("options.ethersSigner has not provider");
  }
  if (!skipSentEvent) {
    cb({ status: "Sent" /* Sent */, txHash });
  }
  const tx = await ethersSigner.provider.getTransactionReceipt(txHash);
  if (!tx) {
    setTimeout(
      () => createTxEventHandler(ethersSigner, txHash, cb, true),
      2e3
    );
    return;
  }
  if (tx.status === 1) {
    cb({
      status: "Success" /* Success */,
      blockHash: tx.blockHash,
      txHash
    });
  } else {
    cb({
      status: "Failed" /* Failed */,
      blockHash: tx.blockHash,
      txHash
    });
  }
}

// src/numbers/decimals.ts
import Big from "big.js";
function toDecimal(number, decimals, maxDecimal = 6, roundType) {
  const dividend = Big(number.toString().replace(/[^0-9]/g, ""));
  const divisor = Big(10).pow(decimals);
  const result = dividend.div(divisor).round(maxDecimal, roundType);
  return result;
}
function toBigInt(amount, decimals) {
  const multiplier = Big(10).pow(decimals);
  const result = Big(amount).mul(multiplier);
  return BigInt(result.toFixed(0, Big.roundDown));
}
function hasDecimalOverflow(fl, maxDecimal) {
  const parts = fl.toString().split(".");
  return parts.length > 1 && parts[1].length > maxDecimal;
}
export {
  ExtrinsicStatus,
  createExtrinsicEventHandler,
  createTxEventHandler,
  getPolkadotApi,
  hasDecimalOverflow,
  toBigInt,
  toDecimal
};
//# sourceMappingURL=index.mjs.map